<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import MultiSelect from '@/Components/Chosen.vue';
import { ref, computed } from 'vue';
import { Head, useForm } from '@inertiajs/vue3';

const form = useForm({
    name: '',
    year: ''
});

const years = generateYears(1949, new Date().getFullYear());

const selectedCarYear = ref(
    form.year ? form.year.split(',').map(Number) : []
);

// Update the form data with the selected car year
const updateSelectedCarYear = (selected) => {
  selectedCarYear.value = selected;
};

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());
const carYearOptions = [];
reversedYears.value.map(item => {
    const year = item;
    carYearOptions.push({
        label: year.toString().replace(',', ''),
        value: year
    });
});

const flashMessage = ref('');

const submit = () => {
    form.year = selectedCarYear.value.join(',');
    form.post(route('admin.products.createmake'), {
        onSuccess: () => {
            form.reset();
            flashMessage.value = "Car make added successfully!";
            selectedCarYear.value = [];
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Add Make" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Add Make <a :href="route('admin.products.allmakes')"  class="back-btn"> Back to list </a></h2>
        </template>

        <div class="py-12 container">

            <div v-if="flashMessage" class="mx-auto font-bold text-green-600">
                <div class="form-row">
                    <div class="col-12">
                        <h4 class="alert alert-success">{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="content-box sm:rounded-lg">
                <form @submit.prevent="submit">

                    <div class="form-row px-3">

                        <div class="mt-4 col-md-12">
                            <InputLabel for="year" value="Year" />
                            <MultiSelect :options="carYearOptions" placeholder="Select Year" :selected="selectedCarYear" @update:selected="updateSelectedCarYear"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="name" value="Car Maker Name" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                    </div>

                    <div class="flex items-center justify-start my-4 col-md-3 col-12">
                        <PrimaryButton class="btn btn-blue" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Add Make
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
